Class: Discordrb::EmbedThumbnail

Inherits:
Object
  • Object
show all
Defined in:
lib/discordrb/data.rb

Overview

An Embed thumbnail for the embed object

Instance Attribute Summary collapse

Instance Attribute Details

#embed ⇒ Embed (readonly)

Returns the embed object this is based on.

Returns:

  • (Embed) —

    the embed object this is based on.



2248
2249
2250
# File 'lib/discordrb/data.rb', line 2248

def embed
  @embed
end

#height ⇒ Integer (readonly)

Returns the height of this thumbnail file, in pixels.

Returns:

  • (Integer) —

    the height of this thumbnail file, in pixels.



2261
2262
2263
# File 'lib/discordrb/data.rb', line 2261

def height
  @height
end

#proxy_url ⇒ String (readonly)

Returns the thumbnail's proxy URL - I'm not sure what exactly this does, but I think it has something to do with CDNs.

Returns:

  • (String) —

    the thumbnail's proxy URL - I'm not sure what exactly this does, but I think it has something to do with CDNs.



2255
2256
2257
# File 'lib/discordrb/data.rb', line 2255

def proxy_url
  @proxy_url
end

#url ⇒ String (readonly)

Returns the CDN URL this thumbnail can be downloaded at.

Returns:

  • (String) —

    the CDN URL this thumbnail can be downloaded at.



2251
2252
2253
# File 'lib/discordrb/data.rb', line 2251

def url
  @url
end

#width ⇒ Integer (readonly)

Returns the width of this thumbnail file, in pixels.

Returns:

  • (Integer) —

    the width of this thumbnail file, in pixels.



2258
2259
2260
# File 'lib/discordrb/data.rb', line 2258

def width
  @width
end