Module: Discordrb::MemberAttributes

Included in:
Member, Recipient
Defined in:
lib/discordrb/data.rb

Overview

Mixin for the attributes members and private members should have

Instance Attribute Summary collapse

Instance Attribute Details

#joined_at ⇒ Time (readonly)

Returns when this member joined the server.

Returns:

  • (Time) —

    when this member joined the server.



330
331
332
# File 'lib/discordrb/data.rb', line 330

def joined_at
  @joined_at
end

#nick ⇒ String? (readonly) Also known as: nickname

Returns the nickname this member has, or nil if it has none.

Returns:

  • (String, nil) —

    the nickname this member has, or nil if it has none.



333
334
335
# File 'lib/discordrb/data.rb', line 333

def nick
  @nick
end

#roles ⇒ Array<Role> (readonly)

Returns the roles this member has.

Returns:

  • (Array<Role>) —

    the roles this member has.



337
338
339
# File 'lib/discordrb/data.rb', line 337

def roles
  @roles
end

#server ⇒ Server (readonly)

Returns the server this member is on.

Returns:

  • (Server) —

    the server this member is on.



340
341
342
# File 'lib/discordrb/data.rb', line 340

def server
  @server
end