Class: Discordrb::ServerBan

Inherits:
Object
  • Object
show all
Defined in:
lib/discordrb/data.rb

Overview

A ban entry on a server

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#reason ⇒ String? (readonly)

Returns the reason the user was banned, if provided.

Returns:

  • (String, nil) —

    the reason the user was banned, if provided



3717
3718
3719
# File 'lib/discordrb/data.rb', line 3717

def reason
  @reason
end

#server ⇒ Server (readonly)

Returns the server this ban belongs to.

Returns:

  • (Server) —

    the server this ban belongs to



3723
3724
3725
# File 'lib/discordrb/data.rb', line 3723

def server
  @server
end

#user ⇒ User (readonly)

Returns the user that was banned.

Returns:

  • (User) —

    the user that was banned



3720
3721
3722
# File 'lib/discordrb/data.rb', line 3720

def user
  @user
end

Instance Method Details

#remove(reason = nil) ⇒ Object Also known as: unban, lift

Removes this ban on the associated user in the server

Parameters:

  • reason (String) (defaults to: nil) —

    the reason for removing the ban



3734
3735
3736
# File 'lib/discordrb/data.rb', line 3734

def remove(reason = nil)
  @server.unban(user, reason)
end